@@ -31,8 +31,9 @@ def get_access_token_for_user(user):
 
 def get_user_from_jwt_raw_token(raw_token):
     token = _jwt.decode(
-        raw_token, _settings.SECRET_KEY, algorithms=_settings.SIMPLE_JWT["ALGORITHM"]
+        raw_token,
+        _settings.SECRET_KEY,
+        algorithms=_settings.SIMPLE_JWT["ALGORITHM"],
     )
-    user = _get_object_or_404(_get_user_model(), id=token["user_id"])
 
-    return user
+    return _get_object_or_404(_get_user_model(), id=token["user_id"])
